@@ -1,9 +1,13 @@
-/* SPDX-License-Identifier: BSD-2 */
+/* SPDX-License-Identifier: BSD-2-Clause */
 /*******************************************************************************
  * Copyright 2017-2018, Fraunhofer SIT sponsored by Infineon Technologies AG
  * All rights reserved.
  ******************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "tss2_mu.h"
 #include "tss2_sys.h"
 #include "tss2_esys.h"
@@ -13,48 +17,7 @@
 #include "esys_mu.h"
 #define LOGMODULE esys
 #include "util/log.h"
-
-/** Store command parameters inside the ESYS_CONTEXT for use during _Finish */
-static void store_input_parameters (
-    ESYS_CONTEXT *esysContext,
-    ESYS_TR signHandle,
-    ESYS_TR objectHandle,
-    const TPM2B_DATA *qualifyingData,
-    const TPM2B_DIGEST *creationHash,
-    const TPMT_SIG_SCHEME *inScheme,
-    const TPMT_TK_CREATION *creationTicket)
-{
-    esysContext->in.CertifyCreation.signHandle = signHandle;
-    esysContext->in.CertifyCreation.objectHandle = objectHandle;
-    if (qualifyingData == NULL) {
-        esysContext->in.CertifyCreation.qualifyingData = NULL;
-    } else {
-        esysContext->in.CertifyCreation.qualifyingDataData = *qualifyingData;
-        esysContext->in.CertifyCreation.qualifyingData =
-            &esysContext->in.CertifyCreation.qualifyingDataData;
-    }
-    if (creationHash == NULL) {
-        esysContext->in.CertifyCreation.creationHash = NULL;
-    } else {
-        esysContext->in.CertifyCreation.creationHashData = *creationHash;
-        esysContext->in.CertifyCreation.creationHash =
-            &esysContext->in.CertifyCreation.creationHashData;
-    }
-    if (inScheme == NULL) {
-        esysContext->in.CertifyCreation.inScheme = NULL;
-    } else {
-        esysContext->in.CertifyCreation.inSchemeData = *inScheme;
-        esysContext->in.CertifyCreation.inScheme =
-            &esysContext->in.CertifyCreation.inSchemeData;
-    }
-    if (creationTicket == NULL) {
-        esysContext->in.CertifyCreation.creationTicket = NULL;
-    } else {
-        esysContext->in.CertifyCreation.creationTicketData = *creationTicket;
-        esysContext->in.CertifyCreation.creationTicket =
-            &esysContext->in.CertifyCreation.creationTicketData;
-    }
-}
+#include "util/aux_util.h"
 
 /** One-Call function for TPM2_CertifyCreation
  *
@@ -222,11 +185,9 @@ Esys_CertifyCreation_Async(
         return r;
     esysContext->state = _ESYS_STATE_INTERNALERROR;
 
-    /* Check and store input parameters */
+    /* Check input parameters */
     r = check_session_feasibility(shandle1, shandle2, shandle3, 1);
     return_state_if_error(r, _ESYS_STATE_INIT, "Check session usage");
-    store_input_parameters(esysContext, signHandle, objectHandle, qualifyingData,
-                           creationHash, inScheme, creationTicket);
 
     /* Retrieve the metadata objects for provided handles */
     r = esys_GetResourceObject(esysContext, signHandle, &signHandleNode);
@@ -259,8 +220,10 @@ Esys_CertifyCreation_Async(
                           "Error in computation of auth values");
 
     esysContext->authsCount = auths.count;
-    r = Tss2_Sys_SetCmdAuths(esysContext->sys, &auths);
-    return_state_if_error(r, _ESYS_STATE_INIT, "SAPI error on SetCmdAuths");
+    if (auths.count > 0) {
+        r = Tss2_Sys_SetCmdAuths(esysContext->sys, &auths);
+        return_state_if_error(r, _ESYS_STATE_INIT, "SAPI error on SetCmdAuths");
+    }
 
     /* Trigger execution and finish the async invocation */
     r = Tss2_Sys_ExecuteAsync(esysContext->sys);
@@ -319,7 +282,8 @@ Esys_CertifyCreation_Finish(
     }
 
     /* Check for correct sequence and set sequence to irregular for now */
-    if (esysContext->state != _ESYS_STATE_SENT) {
+    if (esysContext->state != _ESYS_STATE_SENT &&
+        esysContext->state != _ESYS_STATE_RESUBMISSION) {
         LOG_ERROR("Esys called in bad sequence.");
         return TSS2_ESYS_RC_BAD_SEQUENCE;
     }
@@ -351,22 +315,13 @@ Esys_CertifyCreation_Finish(
     if (r == TPM2_RC_RETRY || r == TPM2_RC_TESTING || r == TPM2_RC_YIELDED) {
         LOG_DEBUG("TPM returned RETRY, TESTING or YIELDED, which triggers a "
             "resubmission: %" PRIx32, r);
-        if (esysContext->submissionCount >= _ESYS_MAX_SUBMISSIONS) {
+        if (esysContext->submissionCount++ >= _ESYS_MAX_SUBMISSIONS) {
             LOG_WARNING("Maximum number of (re)submissions has been reached.");
             esysContext->state = _ESYS_STATE_INIT;
             goto error_cleanup;
         }
         esysContext->state = _ESYS_STATE_RESUBMISSION;
-        r = Esys_CertifyCreation_Async(esysContext,
-                                       esysContext->in.CertifyCreation.signHandle,
-                                       esysContext->in.CertifyCreation.objectHandle,
-                                       esysContext->session_type[0],
-                                       esysContext->session_type[1],
-                                       esysContext->session_type[2],
-                                       esysContext->in.CertifyCreation.qualifyingData,
-                                       esysContext->in.CertifyCreation.creationHash,
-                                       esysContext->in.CertifyCreation.inScheme,
-                                       esysContext->in.CertifyCreation.creationTicket);
+        r = Tss2_Sys_ExecuteAsync(esysContext->sys);
         if (r != TSS2_RC_SUCCESS) {
             LOG_WARNING("Error attempting to resubmit");
             /* We do not set esysContext->state here but inherit the most recent
