@@ -1,9 +1,13 @@
-/* SPDX-License-Identifier: BSD-2 */
+/* SPDX-License-Identifier: BSD-2-Clause */
 /*******************************************************************************
  * Copyright 2017-2018, Fraunhofer SIT sponsored by Infineon Technologies AG
  * All rights reserved.
  ******************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "tss2_mu.h"
 #include "tss2_sys.h"
 #include "tss2_esys.h"
@@ -13,46 +17,7 @@
 #include "esys_mu.h"
 #define LOGMODULE esys
 #include "util/log.h"
-
-/** Store command parameters inside the ESYS_CONTEXT for use during _Finish */
-static void store_input_parameters (
-    ESYS_CONTEXT *esysContext,
-    ESYS_TR parentHandle,
-    const TPM2B_SENSITIVE_CREATE *inSensitive,
-    const TPM2B_PUBLIC *inPublic,
-    const TPM2B_DATA *outsideInfo,
-    const TPML_PCR_SELECTION *creationPCR)
-{
-    esysContext->in.Create.parentHandle = parentHandle;
-    if (inSensitive == NULL) {
-        esysContext->in.Create.inSensitive = NULL;
-    } else {
-        esysContext->in.Create.inSensitiveData = *inSensitive;
-        esysContext->in.Create.inSensitive =
-            &esysContext->in.Create.inSensitiveData;
-    }
-    if (inPublic == NULL) {
-        esysContext->in.Create.inPublic = NULL;
-    } else {
-        esysContext->in.Create.inPublicData = *inPublic;
-        esysContext->in.Create.inPublic =
-            &esysContext->in.Create.inPublicData;
-    }
-    if (outsideInfo == NULL) {
-        esysContext->in.Create.outsideInfo = NULL;
-    } else {
-        esysContext->in.Create.outsideInfoData = *outsideInfo;
-        esysContext->in.Create.outsideInfo =
-            &esysContext->in.Create.outsideInfoData;
-    }
-    if (creationPCR == NULL) {
-        esysContext->in.Create.creationPCR = NULL;
-    } else {
-        esysContext->in.Create.creationPCRData = *creationPCR;
-        esysContext->in.Create.creationPCR =
-            &esysContext->in.Create.creationPCRData;
-    }
-}
+#include "util/aux_util.h"
 
 /** One-Call function for TPM2_Create
  *
@@ -221,11 +186,9 @@ Esys_Create_Async(
         return r;
     esysContext->state = _ESYS_STATE_INTERNALERROR;
 
-    /* Check and store input parameters */
+    /* Check input parameters */
     r = check_session_feasibility(shandle1, shandle2, shandle3, 1);
     return_state_if_error(r, _ESYS_STATE_INIT, "Check session usage");
-    store_input_parameters(esysContext, parentHandle, inSensitive, inPublic,
-                           outsideInfo, creationPCR);
 
     /* Retrieve the metadata objects for provided handles */
     r = esys_GetResourceObject(esysContext, parentHandle, &parentHandleNode);
@@ -252,8 +215,10 @@ Esys_Create_Async(
                           "Error in computation of auth values");
 
     esysContext->authsCount = auths.count;
-    r = Tss2_Sys_SetCmdAuths(esysContext->sys, &auths);
-    return_state_if_error(r, _ESYS_STATE_INIT, "SAPI error on SetCmdAuths");
+    if (auths.count > 0) {
+        r = Tss2_Sys_SetCmdAuths(esysContext->sys, &auths);
+        return_state_if_error(r, _ESYS_STATE_INIT, "SAPI error on SetCmdAuths");
+    }
 
     /* Trigger execution and finish the async invocation */
     r = Tss2_Sys_ExecuteAsync(esysContext->sys);
@@ -324,7 +289,8 @@ Esys_Create_Finish(
     }
 
     /* Check for correct sequence and set sequence to irregular for now */
-    if (esysContext->state != _ESYS_STATE_SENT) {
+    if (esysContext->state != _ESYS_STATE_SENT &&
+        esysContext->state != _ESYS_STATE_RESUBMISSION) {
         LOG_ERROR("Esys called in bad sequence.");
         return TSS2_ESYS_RC_BAD_SEQUENCE;
     }
@@ -382,20 +348,13 @@ Esys_Create_Finish(
     if (r == TPM2_RC_RETRY || r == TPM2_RC_TESTING || r == TPM2_RC_YIELDED) {
         LOG_DEBUG("TPM returned RETRY, TESTING or YIELDED, which triggers a "
             "resubmission: %" PRIx32, r);
-        if (esysContext->submissionCount >= _ESYS_MAX_SUBMISSIONS) {
+        if (esysContext->submissionCount++ >= _ESYS_MAX_SUBMISSIONS) {
             LOG_WARNING("Maximum number of (re)submissions has been reached.");
             esysContext->state = _ESYS_STATE_INIT;
             goto error_cleanup;
         }
         esysContext->state = _ESYS_STATE_RESUBMISSION;
-        r = Esys_Create_Async(esysContext, esysContext->in.Create.parentHandle,
-                              esysContext->session_type[0],
-                              esysContext->session_type[1],
-                              esysContext->session_type[2],
-                              esysContext->in.Create.inSensitive,
-                              esysContext->in.Create.inPublic,
-                              esysContext->in.Create.outsideInfo,
-                              esysContext->in.Create.creationPCR);
+        r = Tss2_Sys_ExecuteAsync(esysContext->sys);
         if (r != TSS2_RC_SUCCESS) {
             LOG_WARNING("Error attempting to resubmit");
             /* We do not set esysContext->state here but inherit the most recent
