@@ -1,9 +1,13 @@
-/* SPDX-License-Identifier: BSD-2 */
+/* SPDX-License-Identifier: BSD-2-Clause */
 /*******************************************************************************
  * Copyright 2017-2018, Fraunhofer SIT sponsored by Infineon Technologies AG
  * All rights reserved.
  ******************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "tss2_mu.h"
 #include "tss2_sys.h"
 #include "tss2_esys.h"
@@ -13,15 +17,14 @@
 #include "esys_mu.h"
 #define LOGMODULE esys
 #include "util/log.h"
+#include "util/aux_util.h"
 
 /** Store command parameters inside the ESYS_CONTEXT for use during _Finish */
 static void store_input_parameters (
     ESYS_CONTEXT *esysContext,
-    ESYS_TR auth,
     ESYS_TR objectHandle,
     TPMI_DH_PERSISTENT persistentHandle)
 {
-    esysContext->in.EvictControl.auth = auth;
     esysContext->in.EvictControl.objectHandle = objectHandle;
     esysContext->in.EvictControl.persistentHandle = persistentHandle;
 }
@@ -178,10 +181,10 @@ Esys_EvictControl_Async(
         return r;
     esysContext->state = _ESYS_STATE_INTERNALERROR;
 
-    /* Check and store input parameters */
+    /* Check input parameters */
     r = check_session_feasibility(shandle1, shandle2, shandle3, 1);
     return_state_if_error(r, _ESYS_STATE_INIT, "Check session usage");
-    store_input_parameters(esysContext, auth, objectHandle, persistentHandle);
+    store_input_parameters(esysContext, objectHandle, persistentHandle);
 
     /* Retrieve the metadata objects for provided handles */
     r = esys_GetResourceObject(esysContext, auth, &authNode);
@@ -217,8 +220,10 @@ Esys_EvictControl_Async(
                           "Error in computation of auth values");
 
     esysContext->authsCount = auths.count;
-    r = Tss2_Sys_SetCmdAuths(esysContext->sys, &auths);
-    return_state_if_error(r, _ESYS_STATE_INIT, "SAPI error on SetCmdAuths");
+    if (auths.count > 0) {
+        r = Tss2_Sys_SetCmdAuths(esysContext->sys, &auths);
+        return_state_if_error(r, _ESYS_STATE_INIT, "SAPI error on SetCmdAuths");
+    }
 
     /* Trigger execution and finish the async invocation */
     r = Tss2_Sys_ExecuteAsync(esysContext->sys);
@@ -272,23 +277,19 @@ Esys_EvictControl_Finish(
     }
 
     /* Check for correct sequence and set sequence to irregular for now */
-    if (esysContext->state != _ESYS_STATE_SENT) {
+    if (esysContext->state != _ESYS_STATE_SENT &&
+        esysContext->state != _ESYS_STATE_RESUBMISSION) {
         LOG_ERROR("Esys called in bad sequence.");
         return TSS2_ESYS_RC_BAD_SEQUENCE;
     }
     esysContext->state = _ESYS_STATE_INTERNALERROR;
-    RSRC_NODE_T *newObjectHandleNode = NULL;
 
     /* Allocate memory for response parameters */
     if (newObjectHandle == NULL) {
         LOG_ERROR("Handle newObjectHandle may not be NULL");
         return TSS2_ESYS_RC_BAD_REFERENCE;
     }
-    *newObjectHandle = esysContext->esys_handle_cnt++;
-    r = esys_CreateResourceObject(esysContext, *newObjectHandle, &newObjectHandleNode);
-    if (r != TSS2_RC_SUCCESS)
-        return r;
-
+    *newObjectHandle = ESYS_TR_NONE;
 
     /*Receive the TPM response and handle resubmissions if necessary. */
     r = Tss2_Sys_ExecuteFinish(esysContext->sys, esysContext->timeout);
@@ -297,24 +298,19 @@ Esys_EvictControl_Finish(
         esysContext->state = _ESYS_STATE_SENT;
         goto error_cleanup;
     }
+
     /* This block handle the resubmission of TPM commands given a certain set of
      * TPM response codes. */
     if (r == TPM2_RC_RETRY || r == TPM2_RC_TESTING || r == TPM2_RC_YIELDED) {
         LOG_DEBUG("TPM returned RETRY, TESTING or YIELDED, which triggers a "
             "resubmission: %" PRIx32, r);
-        if (esysContext->submissionCount >= _ESYS_MAX_SUBMISSIONS) {
+        if (esysContext->submissionCount++ >= _ESYS_MAX_SUBMISSIONS) {
             LOG_WARNING("Maximum number of (re)submissions has been reached.");
             esysContext->state = _ESYS_STATE_INIT;
             goto error_cleanup;
         }
         esysContext->state = _ESYS_STATE_RESUBMISSION;
-        r = Esys_EvictControl_Async(esysContext,
-                                    esysContext->in.EvictControl.auth,
-                                    esysContext->in.EvictControl.objectHandle,
-                                    esysContext->session_type[0],
-                                    esysContext->session_type[1],
-                                    esysContext->session_type[2],
-                                    esysContext->in.EvictControl.persistentHandle);
+        r = Tss2_Sys_ExecuteAsync(esysContext->sys);
         if (r != TSS2_RC_SUCCESS) {
             LOG_WARNING("Error attempting to resubmit");
             /* We do not set esysContext->state here but inherit the most recent
@@ -376,7 +372,8 @@ Esys_EvictControl_Finish(
     return TSS2_RC_SUCCESS;
 
 error_cleanup:
-    Esys_TR_Close(esysContext, newObjectHandle);
+    if (*newObjectHandle != ESYS_TR_NONE)
+        Esys_TR_Close(esysContext, newObjectHandle);
 
     return r;
 }
