@@ -1,9 +1,13 @@
-/* SPDX-License-Identifier: BSD-2 */
+/* SPDX-License-Identifier: BSD-2-Clause */
 /*******************************************************************************
  * Copyright 2017-2018, Fraunhofer SIT sponsored by Infineon Technologies AG
  * All rights reserved.
  ******************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "tss2_mu.h"
 #include "tss2_sys.h"
 #include "tss2_esys.h"
@@ -13,50 +17,7 @@
 #include "esys_mu.h"
 #define LOGMODULE esys
 #include "util/log.h"
-
-/** Store command parameters inside the ESYS_CONTEXT for use during _Finish */
-static void store_input_parameters (
-    ESYS_CONTEXT *esysContext,
-    ESYS_TR authObject,
-    ESYS_TR policySession,
-    const TPM2B_NONCE *nonceTPM,
-    const TPM2B_DIGEST *cpHashA,
-    const TPM2B_NONCE *policyRef,
-    INT32 expiration,
-    const TPMT_SIGNATURE *auth)
-{
-    esysContext->in.PolicySigned.authObject = authObject;
-    esysContext->in.PolicySigned.policySession = policySession;
-    esysContext->in.PolicySigned.expiration = expiration;
-    if (nonceTPM == NULL) {
-        esysContext->in.PolicySigned.nonceTPM = NULL;
-    } else {
-        esysContext->in.PolicySigned.nonceTPMData = *nonceTPM;
-        esysContext->in.PolicySigned.nonceTPM =
-            &esysContext->in.PolicySigned.nonceTPMData;
-    }
-    if (cpHashA == NULL) {
-        esysContext->in.PolicySigned.cpHashA = NULL;
-    } else {
-        esysContext->in.PolicySigned.cpHashAData = *cpHashA;
-        esysContext->in.PolicySigned.cpHashA =
-            &esysContext->in.PolicySigned.cpHashAData;
-    }
-    if (policyRef == NULL) {
-        esysContext->in.PolicySigned.policyRef = NULL;
-    } else {
-        esysContext->in.PolicySigned.policyRefData = *policyRef;
-        esysContext->in.PolicySigned.policyRef =
-            &esysContext->in.PolicySigned.policyRefData;
-    }
-    if (auth == NULL) {
-        esysContext->in.PolicySigned.auth = NULL;
-    } else {
-        esysContext->in.PolicySigned.authData = *auth;
-        esysContext->in.PolicySigned.auth =
-            &esysContext->in.PolicySigned.authData;
-    }
-}
+#include "util/aux_util.h"
 
 /** One-Call function for TPM2_PolicySigned
  *
@@ -229,11 +190,9 @@ Esys_PolicySigned_Async(
         return r;
     esysContext->state = _ESYS_STATE_INTERNALERROR;
 
-    /* Check and store input parameters */
+    /* Check input parameters */
     r = check_session_feasibility(shandle1, shandle2, shandle3, 0);
     return_state_if_error(r, _ESYS_STATE_INIT, "Check session usage");
-    store_input_parameters(esysContext, authObject, policySession, nonceTPM,
-                           cpHashA, policyRef, expiration, auth);
 
     /* Retrieve the metadata objects for provided handles */
     r = esys_GetResourceObject(esysContext, authObject, &authObjectNode);
@@ -264,8 +223,10 @@ Esys_PolicySigned_Async(
                           "Error in computation of auth values");
 
     esysContext->authsCount = auths.count;
-    r = Tss2_Sys_SetCmdAuths(esysContext->sys, &auths);
-    return_state_if_error(r, _ESYS_STATE_INIT, "SAPI error on SetCmdAuths");
+    if (auths.count > 0) {
+        r = Tss2_Sys_SetCmdAuths(esysContext->sys, &auths);
+        return_state_if_error(r, _ESYS_STATE_INIT, "SAPI error on SetCmdAuths");
+    }
 
     /* Trigger execution and finish the async invocation */
     r = Tss2_Sys_ExecuteAsync(esysContext->sys);
@@ -327,7 +288,8 @@ Esys_PolicySigned_Finish(
     }
 
     /* Check for correct sequence and set sequence to irregular for now */
-    if (esysContext->state != _ESYS_STATE_SENT) {
+    if (esysContext->state != _ESYS_STATE_SENT &&
+        esysContext->state != _ESYS_STATE_RESUBMISSION) {
         LOG_ERROR("Esys called in bad sequence.");
         return TSS2_ESYS_RC_BAD_SEQUENCE;
     }
@@ -359,23 +321,13 @@ Esys_PolicySigned_Finish(
     if (r == TPM2_RC_RETRY || r == TPM2_RC_TESTING || r == TPM2_RC_YIELDED) {
         LOG_DEBUG("TPM returned RETRY, TESTING or YIELDED, which triggers a "
             "resubmission: %" PRIx32, r);
-        if (esysContext->submissionCount >= _ESYS_MAX_SUBMISSIONS) {
+        if (esysContext->submissionCount++ >= _ESYS_MAX_SUBMISSIONS) {
             LOG_WARNING("Maximum number of (re)submissions has been reached.");
             esysContext->state = _ESYS_STATE_INIT;
             goto error_cleanup;
         }
         esysContext->state = _ESYS_STATE_RESUBMISSION;
-        r = Esys_PolicySigned_Async(esysContext,
-                                    esysContext->in.PolicySigned.authObject,
-                                    esysContext->in.PolicySigned.policySession,
-                                    esysContext->session_type[0],
-                                    esysContext->session_type[1],
-                                    esysContext->session_type[2],
-                                    esysContext->in.PolicySigned.nonceTPM,
-                                    esysContext->in.PolicySigned.cpHashA,
-                                    esysContext->in.PolicySigned.policyRef,
-                                    esysContext->in.PolicySigned.expiration,
-                                    esysContext->in.PolicySigned.auth);
+        r = Tss2_Sys_ExecuteAsync(esysContext->sys);
         if (r != TSS2_RC_SUCCESS) {
             LOG_WARNING("Error attempting to resubmit");
             /* We do not set esysContext->state here but inherit the most recent
