@@ -1,9 +1,13 @@
-/* SPDX-License-Identifier: BSD-2 */
+/* SPDX-License-Identifier: BSD-2-Clause */
 /*******************************************************************************
  * Copyright 2017-2018, Fraunhofer SIT sponsored by Infineon Technologies AG
  * All rights reserved.
  ******************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "tss2_mu.h"
 #include "tss2_sys.h"
 #include "tss2_esys.h"
@@ -13,6 +17,7 @@
 #include "esys_mu.h"
 #define LOGMODULE esys
 #include "util/log.h"
+#include "util/aux_util.h"
 
 /** Store command parameters inside the ESYS_CONTEXT for use during _Finish */
 static void store_input_parameters (
@@ -203,7 +208,7 @@ Esys_StartAuthSession_Async(
         return r;
     esysContext->state = _ESYS_STATE_INTERNALERROR;
 
-    /* Check and store input parameters */
+    /* Check input parameters */
     r = check_session_feasibility(shandle1, shandle2, shandle3, 0);
     return_state_if_error(r, _ESYS_STATE_INIT, "Check session usage");
     store_input_parameters(esysContext, tpmKey, bind, nonceCaller, sessionType,
@@ -260,8 +265,10 @@ Esys_StartAuthSession_Async(
                           "Error in computation of auth values");
 
     esysContext->authsCount = auths.count;
-    r = Tss2_Sys_SetCmdAuths(esysContext->sys, &auths);
-    return_state_if_error(r, _ESYS_STATE_INIT, "SAPI error on SetCmdAuths");
+    if (auths.count > 0) {
+        r = Tss2_Sys_SetCmdAuths(esysContext->sys, &auths);
+        return_state_if_error(r, _ESYS_STATE_INIT, "SAPI error on SetCmdAuths");
+    }
 
     /* Trigger execution and finish the async invocation */
     r = Tss2_Sys_ExecuteAsync(esysContext->sys);
@@ -316,7 +323,8 @@ Esys_StartAuthSession_Finish(
     }
 
     /* Check for correct sequence and set sequence to irregular for now */
-    if (esysContext->state != _ESYS_STATE_SENT) {
+    if (esysContext->state != _ESYS_STATE_SENT &&
+        esysContext->state != _ESYS_STATE_RESUBMISSION) {
         LOG_ERROR("Esys called in bad sequence.");
         return TSS2_ESYS_RC_BAD_SEQUENCE;
     }
@@ -334,18 +342,14 @@ Esys_StartAuthSession_Finish(
         return r;
 
     IESYS_RESOURCE *rsrc = &sessionHandleNode->rsrc;
-    rsrc->misc.rsrc_session.sessionAttributes =
-        TPMA_SESSION_CONTINUESESSION;
-    rsrc->misc.rsrc_session.sessionType =
-        esysContext->in.StartAuthSession.sessionType;
-    rsrc->misc.rsrc_session.authHash =
-        esysContext->in.StartAuthSession.authHash;
-    rsrc->misc.rsrc_session.symmetric =
-        *esysContext->in.StartAuthSession.symmetric;
-    rsrc->misc.rsrc_session.nonceCaller =
-        esysContext->in.StartAuthSession.nonceCallerData;
+    rsrc->handle = ESYS_TR_NONE;
+    rsrc->misc.rsrc_session.sessionAttributes = TPMA_SESSION_CONTINUESESSION;
+    rsrc->misc.rsrc_session.sessionType = esysContext->in.StartAuthSession.sessionType;
+    rsrc->misc.rsrc_session.authHash = esysContext->in.StartAuthSession.authHash;
+    rsrc->misc.rsrc_session.symmetric = *esysContext->in.StartAuthSession.symmetric;
+    rsrc->misc.rsrc_session.nonceCaller = esysContext->in.StartAuthSession.nonceCallerData;
 
-    /*Receive the TPM response and handle resubmissions if necessary. */
+    /* Receive the TPM response and handle resubmissions if necessary. */
     r = Tss2_Sys_ExecuteFinish(esysContext->sys, esysContext->timeout);
     if ((r & ~TSS2_RC_LAYER_MASK) == TSS2_BASE_RC_TRY_AGAIN) {
         LOG_DEBUG("A layer below returned TRY_AGAIN: %" PRIx32, r);
@@ -357,22 +361,13 @@ Esys_StartAuthSession_Finish(
     if (r == TPM2_RC_RETRY || r == TPM2_RC_TESTING || r == TPM2_RC_YIELDED) {
         LOG_DEBUG("TPM returned RETRY, TESTING or YIELDED, which triggers a "
             "resubmission: %" PRIx32, r);
-        if (esysContext->submissionCount >= _ESYS_MAX_SUBMISSIONS) {
+        if (esysContext->submissionCount++ >= _ESYS_MAX_SUBMISSIONS) {
             LOG_WARNING("Maximum number of (re)submissions has been reached.");
             esysContext->state = _ESYS_STATE_INIT;
             goto error_cleanup;
         }
         esysContext->state = _ESYS_STATE_RESUBMISSION;
-        r = Esys_StartAuthSession_Async(esysContext,
-                                        esysContext->in.StartAuthSession.tpmKey,
-                                        esysContext->in.StartAuthSession.bind,
-                                        esysContext->session_type[0],
-                                        esysContext->session_type[1],
-                                        esysContext->session_type[2],
-                                        esysContext->in.StartAuthSession.nonceCaller,
-                                        esysContext->in.StartAuthSession.sessionType,
-                                        esysContext->in.StartAuthSession.symmetric,
-                                        esysContext->in.StartAuthSession.authHash);
+        r = Tss2_Sys_ExecuteAsync(esysContext->sys);
         if (r != TSS2_RC_SUCCESS) {
             LOG_WARNING("Error attempting to resubmit");
             /* We do not set esysContext->state here but inherit the most recent
@@ -449,11 +444,11 @@ Esys_StartAuthSession_Finish(
             secret_size += keyHash_size;
         if (bind != ESYS_TR_NONE && bindNode != NULL)
             secret_size += bindNode->auth.size;
-        if (secret_size == 0) {
-            return_error(TSS2_ESYS_RC_GENERAL_FAILURE,
-                         "Invalid secret size (0).");
-        }
-        uint8_t *secret = malloc(secret_size);
+        /*
+         * A non null pointer for secret is required by the subsequent functions,
+         * hence a malloc is called with size 1 if secret_size is zero.
+         */
+        uint8_t *secret = malloc(secret_size ? secret_size : 1);
         if (secret == NULL) {
             LOG_ERROR("Out of memory.");
             return TSS2_ESYS_RC_MEMORY;
@@ -487,11 +482,24 @@ Esys_StartAuthSession_Finish(
 
         sessionHandleNode->rsrc.misc.rsrc_session.sessionKey.size = authHash_size;
     }
+    size_t offset = 0;
+    r = Tss2_MU_TPM2_HANDLE_Marshal(sessionHandleNode->rsrc.handle,
+                                    &sessionHandleNode->rsrc.name.name[0],
+                                    sizeof(sessionHandleNode->rsrc.name.name),
+                                    &offset);
+    goto_if_error(r, "Marshal session name", error_cleanup);
+
+    sessionHandleNode->rsrc.name.size = offset;
     esysContext->state = _ESYS_STATE_INIT;
 
     return TSS2_RC_SUCCESS;
 
 error_cleanup:
+    if (sessionHandleNode->rsrc.handle != ESYS_TR_NONE) {
+        r = Esys_FlushContext(esysContext, sessionHandleNode->rsrc.handle);
+        if (r != TSS2_RC_SUCCESS)
+            LOG_ERROR("FlushContext failed.");
+    }
     Esys_TR_Close(esysContext, sessionHandle);
 
     return r;
