@@ -1,4 +1,4 @@
-/* SPDX-License-Identifier: BSD-2 */
+/* SPDX-License-Identifier: BSD-2-Clause */
 /***********************************************************************
  * Copyright (c) 2017-2018, Intel Corporation
  *
@@ -22,7 +22,7 @@
 
 /* environment variables holding TCTI config */
 #define ENV_TCTI_NAME      "TPM20TEST_TCTI_NAME"
-#define ENV_DEVICE_FILE    "TPM2OTEST_DEVICE_FILE"
+#define ENV_DEVICE_FILE    "TPM20TEST_DEVICE_FILE"
 #define ENV_SOCKET_ADDRESS "TPM20TEST_SOCKET_ADDRESS"
 #define ENV_SOCKET_PORT    "TPM20TEST_SOCKET_PORT"
 
@@ -30,13 +30,14 @@ typedef enum {
     UNKNOWN_TCTI,
     DEVICE_TCTI,
     SOCKET_TCTI,
+    FUZZING_TCTI,
     N_TCTI,
 } TCTI_TYPE;
 
 typedef struct {
     TCTI_TYPE tcti_type;
-    char *device_file;
-    char *socket_address;
+    const char *device_file;
+    const char *socket_address;
     uint16_t socket_port;
 } test_opts_t;
 
